pub enum StreamVideoType {
Camera,
Screen,
Custom,
__Unknown,
}Expand description
Different type of video streams supported.
Variants
Camera
This is a video stream coming from a camera.
Screen
This is a video stream coming from a screen capture.
Custom
This is a custom video stream.
__Unknown
Unknown video stream type.